@@ -10,18 +10,19 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 1112 2008-10-24 03:15:05Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 1207 2008-11-14 12:42:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
 
 class BaseFrameContainer
 {
-	var $_db;	// DB接続オブジェクト
+	private $_db;	// DB接続オブジェクト
 	const ADMIN_TEMPLATE = '_admin';
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
 	const SITE_IN_PUBLIC = 'site_in_public';			// サイト公開状況
 	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
+	const CONFIG_KEY_MSG_TEMPLATE = 'msg_template';			// メッセージ用テンプレート取得キー
 	
 	/**
 	 * コンストラクタ
@@ -490,14 +491,17 @@ class BaseFrameContainer
 		
 		// ページIDを設定
 		$basename = 'admin_index';
-		$gEnvManager->setCurrentPageId($basename);
+		$gEnvManager->setCurrentPageId($basename);								// ここでデフォルトページサブIDが再設定される
+		$gEnvManager->setCurrentPageSubId($gEnvManager->getDefaultPageSubId());// デフォルトページサブIDをカレントにする
 		
-		// 管理用テンプレート
-		$curTemplate = self::ADMIN_TEMPLATE;
+		// テンプレートの設定
+		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
+		$curTemplate = $this->_db->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
+		if (empty($curTemplate)) $curTemplate = self::ADMIN_TEMPLATE;// 管理用テンプレート
 
 		// カレントのテンプレートIDを設定
 		$gEnvManager->setCurrentTemplateId($curTemplate);
-
+		
 		// ################### バッファリング開始 ######################
 		// ob_end_flush()までの出力をバッファリングする
 		ob_start();
