@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 1182 2008-11-07 04:25:44Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 1240 2008-11-16 05:41:26Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -172,6 +172,25 @@ class BaseWidgetContainer
 	{
 		echo $this->tmpl->getParsedTemplate('_widget');
 	}
+	/**
+	 * ヘルプ文字列を変換
+	 *
+	 * @param string $templateName		テンプレート名
+	 * @return なし
+	 */
+	function convertHelp($templateName)
+	{
+		global $gEnvManager;
+		global $gHelpManager;
+		
+		// ヘルプを設定
+		$helpKeys = $gHelpManager->loadHelp($gEnvManager->getCurrentWidgetId());
+		for ($i = 0; $i < count($helpKeys); $i++){
+			$key = $helpKeys[$i];
+			$helpText = $gHelpManager->getHelpText($key);
+			$this->tmpl->addVar($templateName, self::HELP_HEAD . $key, $helpText);
+		}
+	}
 	/**
 	 * patTemplateを使用した汎用データ変換処理
 	 *
