@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseDb.php 1054 2008-10-02 09:51:56Z fishbone $
+ * @version    SVN: $Id: baseDb.php 1242 2008-11-16 11:35:06Z fishbone $
  * @link       http://www.magic3.org
  */
 class BaseDb
@@ -458,6 +458,7 @@ class BaseDb
 		$char              = '';
 		$string_start      = '';
 		$in_string         = false;
+		$ret = array();		// 戻り値初期化
 
 		for ($i = 0; $i < $sql_len; $i++){
 			$char = $sql[$i];
@@ -504,7 +505,7 @@ class BaseDb
 			} else if (($char == '"') || ($char == '\'') || ($char == '`')){
 				$in_string    = true;
 				$string_start = $char;
-			} else if ($char == '#' || ($char == ' ' && $i > 1 && $sql[$i-2] . $sql[$i-1] == '--')){		// コメント行の場合
+			} else if ($char == '#' || ($char == ' ' && $i > 1 && $sql[$i-2] . $sql[$i-1] == '--')){		// 「#」「-- 」形式のコメント行の場合
 				// starting position of the comment depends on the comment type
 				$start_of_comment = (($sql[$i] == '#') ? $i : $i-2);
 				// if no "\n" exits in the remaining string, checks for "\r"
@@ -514,7 +515,8 @@ class BaseDb
 										: strpos(' ' . $sql, "\015", $i+2);
 				if (!$end_of_comment){
 					$last = trim(substr($sql, 0, $i-1));
-					if (!empty($last) && $last[0] != '#'){		// コメント行でなければ追加
+					//if (!empty($last) && $last[0] != '#'){		// コメント行でなければ追加
+					if (!empty($last) && ($last[0] != '#' && $last[0] != '-')){		// コメント行でなければ追加
 						$ret[] = $last;
 					}
 					return true;
@@ -851,7 +853,6 @@ class BaseDb
 		$ret = self::_splitSql($lines, $fileData);
 		if ($ret){
 			$lineCount = count($lines);
-
 			for ($i = 0; $i < $lineCount; $i++){
 				// DBのタイプに合わせてスクリプトを変換
 				if (self::$_dbType == M3_DB_TYPE_MYSQL){		// MySQLの場合
