@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 1181 2008-11-07 04:05:22Z fishbone $
+ * @version    SVN: $Id: systemDb.php 1205 2008-11-14 06:47:47Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -235,6 +235,30 @@ class SystemDb extends BaseDb
 		if ($ret) $retValue = $row['pg_default_sub_id'];
 		return $retValue;
 	}
+	/**
+	 * デフォルトのページサブIDの更新
+	 *
+	 * @param string $pageId	ページID
+	 * @param string $pageSubId	ページサブID
+	 * @return bool				true=成功、false=失敗
+	 */
+	function updateDefaultPageSubId($pageId, $pageSubId)
+	{
+		// トランザクション開始
+		$this->startTransaction();
+		
+		$queryStr  = 'UPDATE _page_id ';
+		$queryStr .=   'SET ';
+		$queryStr .=     'pg_default_sub_id = ? ';
+		$queryStr .=   'WHERE pg_id = ? ';
+		$queryStr .=     'AND pg_type = 0 ';		// ページID
+		$queryStr .=     'AND pg_editable = true ';		// 編集可能項目のみ更新
+		$this->execStatement($queryStr, array($pageSubId, $pageId));
+
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * 指定のページがアクセス可能なページかチェック
 	 *
@@ -249,7 +273,7 @@ class SystemDb extends BaseDb
 		$queryStr .=  'WHERE pg_type = 0 AND pg_id = ?';
 		$ret = $this->selectRecord($queryStr, array($pageId), $row);
 		if ($ret){
-			if (!$row['pg_is_public']) return false;
+			if (!$row['pg_active']) return false;
 		} else {
 			return false;
 		}
@@ -259,7 +283,7 @@ class SystemDb extends BaseDb
 		$queryStr .=  'WHERE pg_type = 1 AND pg_id = ?';
 		$ret = $this->selectRecord($queryStr, array($pageSubId), $row);
 		if ($ret){
-			if (!$row['pg_is_public']) return false;
+			if (!$row['pg_active']) return false;
 		} else {
 			return false;
 		}
@@ -318,7 +342,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   'AND pd_visible = true ';			// ウィジェットは表示中
 		$queryStr .=   'AND wd_deleted = false ';			// ウィジェットは削除されていない
 		$queryStr .=   'AND wd_enable_operation = true ';	// 単体実行可能
-		$queryStr .=   'AND pg_is_public = true ';			// 公開中のページ
+		$queryStr .=   'AND pg_active = true ';			// 公開中のページ
 		$params = array($widgetId, $setId);
 		$ret = $this->isRecordExists($queryStr, $params);
 		return $ret;
@@ -435,7 +459,7 @@ class SystemDb extends BaseDb
 		$queryStr .= 'WHERE pd_id = ? ';
 		$queryStr .=   'AND pd_widget_id = ? ';
 		$queryStr .=   'AND pd_set_id = ? ';
-		$queryStr .=   'AND pg_is_public = true ';			// 公開中のページ
+		$queryStr .=   'AND pg_active = true ';			// 公開中のページ
 		$queryStr .= 'ORDER BY idx';
 		$retValue = $this->selectRecords($queryStr, array($pageId, $widgetId, $setId), $rows);
 		return $retValue;
@@ -1890,7 +1914,7 @@ class SystemDb extends BaseDb
 		// トランザクション開始
 		$this->startTransaction();
 		
-		$sql = "INSERT INTO _error_log (el_type, el_method, el_message, el_access_log_serial, el_dt) VALUES (?, ?, ?, ?, now())";
+		$sql = "INSERT INTO _operation_log (ol_type, ol_method, ol_message, ol_access_log_serial, ol_dt) VALUES (?, ?, ?, ?, now())";
 		$params = array($type, $method, $message, $logSerial);
 		$this->execStatement($sql, $params);
 
