@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1187 2008-11-07 09:54:10Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1238 2008-11-16 02:30:15Z fishbone $
  * @link       http://www.magic3.org
  */
 class PageManager
@@ -48,13 +48,16 @@ class PageManager
 	private $isAbort;					// ページ作成処理を中断するかどうか
 	private $libFiles;					// javascript追加用ライブラリ
 	private $pageDefRev = 234;				// 画面定義のリビジョン番号
+	private $headSubTitle = array();				// ヘッドタグサブタイトル
+	const CONFIG_KEY_HEAD_TITLE_FORMAT = 'head_title_format';		// ヘッダ作成用フォーマット
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理用ウィジェットのウィジェットID
 	const CONTENT_TYPE_WIKI = 'wiki';		// ページのコンテンツタイプ(Wiki)
 	const WIDGET_ID_TAG_START = '{{WIDGETID:';		// 遅延実行用タグ
 	const WIDGET_ID_TAG_END = '}}';		// 遅延実行用タグ
 	const WIDGET_ID_SEPARATOR = ',';
-	const HEAD_TAG_KEYWORDS		= 	'{{HEAD_KEYWORDS}}';			// HTMLヘッダのkeywords埋め込み用タグ
-	const HEAD_TAG_DESCRIPTION	= 	'{{HEAD_DESCRIPTION}}';			// HTMLヘッダのdescription埋め込み用タグ
+//	const HEAD_TAG_KEYWORDS		= 	'{{HEAD_KEYWORDS}}';			// HTMLヘッダのkeywords埋め込み用タグ
+//	const HEAD_TAG_DESCRIPTION	= 	'{{HEAD_DESCRIPTION}}';			// HTMLヘッダのdescription埋め込み用タグ
+	const HEAD_TAG_DESC			= 	'{{HEAD_DESC}}';			// HTMLヘッダ出力用タグ
 	const HEAD_TAG_CSS			= 	'{{HEAD_CSS}}';			// HTMLヘッダのCSS埋め込み用タグ
 	const WIDGET_ICON_IMG_SIZE = 32;			// ウィジェットアイコンサイズ
 	const POSITION_TAG_HEAD = 'm3pos_';			// ポジションの識別用タグIDヘッダ
@@ -202,6 +205,20 @@ class PageManager
 	{
 		$this->headKeywords = $str;
 	}
+	/**
+	 * HTMLヘッダ「title」のサブタイトル出力する文字列を設定
+	 *
+	 * @param string,array $str   出力文字列
+	 */
+	function setHeadSubTitle($str)
+	{
+		// 配列で格納
+		if (is_array($str)){
+			$this->headSubTitle = $str;
+		} else if (is_string($str) && !empty($str)){
+			$this->headSubTitle = array($str);
+		}
+	}
 	/**
 	 * HTMLヘッダに出力するCSSの文字列を設定
 	 *
@@ -669,20 +686,60 @@ class PageManager
 		
 		// ##### ヘッダ部分の置換 #####
 		if ($this->outputHead){				// HTMLヘッダ出力を行っているとき
+			$replaceStr = '';
+			// 画面タイトル
+			$titleItemCount = 0;		// タイトル項目数
+			$defaultTitle = trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_TITLE));
+			if (!empty($defaultTitle)) $titleItemCount++;
+			if (!empty($this->headSubTitle)){		// サブタイトルが設定されているとき
+				$titleItemCount += count($this->headSubTitle);
+			}
+			// タイトルフォーマットを取得
+			$title = '';
+			if ($titleItemCount > 0){
+				$format = $this->db->getSystemConfig(self::CONFIG_KEY_HEAD_TITLE_FORMAT);
+				if (empty($format)){
+					$title = htmlspecialchars($defaultTitle);
+				} else {
+					$formats = explode(';', $format);
+					$titleItemCount = ($titleItemCount > count($formats)) ? count($formats) : $titleItemCount;
+					$title = $formats[$titleItemCount -1];
+					$number = 1;
+					if (!empty($defaultTitle)){
+						$title = str_replace('$1', htmlspecialchars($defaultTitle), $title);
+						$number++;
+					}
+					for ($i = 0; $i < count($this->headSubTitle); $i++){
+						$key = '$' . $number;
+						$value = htmlspecialchars(trim($this->headSubTitle[$i]));
+						$title = str_replace($key, $value, $title);
+						$number++;
+					}
+				}
+			}
+			if (!empty($title)) $replaceStr .= '<title>' . $title . '</title>' . M3_NL;
+
 			// サイトの説明
-			if (empty($this->headDescription)){		// 空のときはタグを消去
+			/*if (empty($this->headDescription)){		// 空のときはタグを消去
 				$destBuf = str_replace(self::HEAD_TAG_DESCRIPTION, '', $destBuf);
 			} else {
 				$replaceStr = '<meta name="description" content="' . htmlspecialchars($this->headDescription) . '" />' . M3_NL;
 				$destBuf = str_replace(self::HEAD_TAG_DESCRIPTION, $replaceStr, $destBuf);
-			}
+			}*/
+			if (!empty($this->headDescription)) $replaceStr .= '<meta name="description" content="' . htmlspecialchars($this->headDescription) . '" />' . M3_NL;
+			
 			// 検索エンジン用キーワード
-			if (empty($this->headKeywords)){		// 空のときはタグを消去
+			/*if (empty($this->headKeywords)){		// 空のときはタグを消去
 				$destBuf = str_replace(self::HEAD_TAG_KEYWORDS, '', $destBuf);
 			} else {
 				$replaceStr = '<meta name="keywords" content="' . htmlspecialchars($this->headKeywords) . '" />' . M3_NL;
 				$destBuf = str_replace(self::HEAD_TAG_KEYWORDS, $replaceStr, $destBuf);
-			}
+			}*/
+			if (!empty($this->headKeywords)) $replaceStr .= '<meta name="keywords" content="' . htmlspecialchars($this->headKeywords) . '" />' . M3_NL;
+			
+			// HTMLヘッダのデータ埋め込み
+			$destBuf = str_replace(self::HEAD_TAG_DESC, $replaceStr, $destBuf);
+			
 			// HEADタグに埋め込むCSS
 			if (count($this->headCss) > 0){
 				$replaceStr = '<style type="text/css">' . M3_NL;
@@ -1174,8 +1231,9 @@ class PageManager
 		// ##### タグ変換用のタグを埋め込む #####
 		// ウィジェット単体実行のときはタグを埋め込まない
 		if (!$this->showWidget){
-			echo self::HEAD_TAG_KEYWORDS;		// HTMLヘッダのkeywords埋め込み用タグ
-			echo self::HEAD_TAG_DESCRIPTION;	// HTMLヘッダのdescription埋め込み用タグ
+			//echo self::HEAD_TAG_KEYWORDS;		// HTMLヘッダのkeywords埋め込み用タグ
+			//echo self::HEAD_TAG_DESCRIPTION;	// HTMLヘッダのdescription埋め込み用タグ
+			echo self::HEAD_TAG_DESC;			// HTMLヘッダの埋め込みデータ
 		}
 		// 検索ロボットへの指示
 		$robots = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_ROBOTS)));
@@ -1201,12 +1259,6 @@ class PageManager
 		// outputs link tag for page
 		echo '<link rel="shortcut icon" href="' . $icon .'" />' . M3_NL;
 		
-		// ######## 画面タイトル ##########
-		// 画面ごとにタイトルを変更する場合はここを修正
-		$title = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_TITLE)));
-		if (!empty($title)){
-			echo '<title>' . $title . '</title>' . M3_NL;
-		}
 		// ##### タグ変換用のタグを埋め込む #####
 		// HTMLヘッダのCSS埋め込み用タグ
 		//if (!$this->showWidget){		// ウィジェット単体実行のときはタグを埋め込まない
@@ -1556,7 +1608,11 @@ class PageManager
 			$imageTag .= ' />';
 			// 定義名
 			if (empty($rows[$i]['pd_config_name'])){
-				$configName = '';
+				if ($rows[$i]['wd_use_instance_def'] && $configId == 0){		// インスタンス定義が必要で未定義のとき
+					$configName = '<span style="color:red;">[未設定]</span>';
+				} else {
+					$configName = '';
+				}
 			} else {
 				$configName = '[' . $rows[$i]['pd_config_name'] . ']';
 			}
