@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: requestManager.php 1087 2008-10-18 10:11:29Z fishbone $
+ * @version    SVN: $Id: requestManager.php 1178 2008-11-05 06:44:00Z fishbone $
  * @link       http://www.magic3.org
  */
 class RequestManager
@@ -315,6 +315,27 @@ class RequestManager
 		// 設定したクッキー値を保存
 		$this->tmpCookie[$name] = $value;		// クッキー送信前のクッキー格納データ
 	}
+	/**
+	 * クエリー文字列中のWikiページ名を取得
+	 *
+	 * @return string			Wikiページ名、空の時はWikiページ名なし
+	 */
+	public function getWikiPageFromQuery()
+	{
+		$wikiPage = '';
+		$args = explode('&', $_SERVER['QUERY_STRING']);// 「&」で分割
+		for ($i = 0; $i < count($args); $i++){
+			$line = $args[$i];
+			$pos = strpos($line, '=');
+			if ($pos){		// 「=」が存在するとき
+				//list($key, $value) = explode('=', $line);
+			} else {
+				$wikiPage = $line;
+				break;
+			}
+		}
+		return $wikiPage;
+	}
 	/**
 	 * 文字のエスケープ処理
 	 *
