@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 1054 2008-10-02 09:51:56Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 1235 2008-11-16 00:26:48Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -40,19 +40,19 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$this->sysDb = $gInstanceManager->getSytemDbObject();
 		
 		// 実行SQLスクリプトファイルの定義
-		$this->createTableScripts = array(	array(	'filename' 		=> 'mysql_create_base.sql',					// ファイル名
+		$this->createTableScripts = array(	array(	'filename' 		=> 'create_base.sql',					// ファイル名
 													'name'			=> 'システム基本テーブル作成',				// 表示名
 													'description'	=> 'システムで最小限必要なテーブルの作成'),	// 説明
-											array(	'filename' 		=> 'mysql_insert_base.sql',					// ファイル名
+											array(	'filename' 		=> 'insert_base.sql',					// ファイル名
 													'name'			=> 'システム基本データ登録',				// 表示名
 													'description'	=> 'システムで最小限必要なデータの登録'),	// 説明
-											array(	'filename' 		=> 'mysql_create_standard.sql',					// ファイル名
+											array(	'filename' 		=> 'create_std.sql',					// ファイル名
 													'name'			=> 'システム標準テーブル作成',				// 表示名
 													'description'	=> 'システムを通常使用するのに必要なテーブルの作成'),	// 説明
-											array(	'filename' 		=> 'mysql_insert_standard.sql',					// ファイル名
+											array(	'filename' 		=> 'insert_std.sql',					// ファイル名
 													'name'			=> 'システム標準データ登録',				// 表示名
 													'description'	=> 'システムを通常使用するのに必要なデータの登録'),	// 説明
-											array(	'filename' 		=> 'mysql_create_ec.sql',					// ファイル名
+											array(	'filename' 		=> 'create_ec.sql',					// ファイル名
 													'name'			=> 'Eコマース用テーブル',				// 表示名
 													'description'	=> 'Eコマース用テーブルの作成'));	// 説明
 	}
@@ -90,9 +90,13 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		if ($act == ''){
 		} else if ($act == 'done'){
 			// ##### SQLスクリプトを実行 #####
+			$filename = '';
 			for ($i = 0; $i < count($this->createTableScripts); $i++){
 				$ret = $gDbManager->execInitScriptFile($this->createTableScripts[$i]['filename'], $errors);
-				if (!$ret) break;// 異常終了の場合
+				if (!$ret){
+					$filename = $this->createTableScripts[$i]['filename'];
+					break;// 異常終了の場合
+				}
 			}
 			
 			// ##### 初期データ登録 #####
@@ -105,7 +109,9 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 			if ($ret){// 正常終了の場合
 				$gPageManager->redirect('?task=initother&install_type=' . $type);
 			} else {
-				$this->setMsg(self::MSG_APP_ERR, "ＤＢ初期化に失敗しました");
+				$msg = 'ＤＢ初期化に失敗しました';
+				if (!empty($filename)) $msg .= '(スクリプト名=' . $filename . ')';
+				$this->setMsg(self::MSG_APP_ERR, $msg);
 			}
 			if (!empty($errors)){
 				foreach ($errors as $error) {
