@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 1070 2008-10-11 06:39:03Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 1231 2008-11-15 07:14:29Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -261,6 +261,16 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","work_dir_access", $data);		// 一時ディレクトリの書き込み権限
 		
+		// 画像格納ディレクトリパス
+		$path = $gEnvManager->getResourcePath();
+		$this->tmpl->addVar("_widget", "resource_dir", $path);
+		if (is_writable($path)){
+			$data = '<b><font color="green">書き込み可能</font></b>';
+		} else {
+			$data = '<b><font color="red">書き込み不可</font></b>';
+		}
+		$this->tmpl->addVar("_widget", "resource_dir_access", $data);
+		
 		// phpinfo出力へのURL
 		//$phpinfoUrl = '?task=phpinfo&menu=off';			// メニューは非表示にする
 		$phpinfoUrl = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_SHOW_PHPINFO;			// phpinfo画面
