@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainEditmenuWidgetContainer.php 1020 2008-09-18 04:54:56Z fishbone $
+ * @version    SVN: $Id: admin_mainEditmenuWidgetContainer.php 1238 2008-11-16 02:30:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -58,7 +58,7 @@ class admin_mainEditmenuWidgetContainer extends BaseWidgetContainer
 									array('task' => 'pagedef_mobile',	'name' => '携帯用画面編集',		'desc' => '携帯用Webサイトの画面を作成します。'),
 									array('task' => 'widgetlist',		'name' => 'ウィジェット管理',	'desc' => 'ウィジェットの管理を行います。'),
 									array('task' => 'templist',			'name' => 'テンプレート管理',	'desc' => 'テンプレートの管理を行います。'),
-									array('task' => 'pageother',		'name' => 'システムマスター管理', 'desc' => 'システムに関するデータの管理を行います。'),
+									array('task' => 'master',			'name' => 'システムマスター管理', 'desc' => 'システムに関するマスターデータの管理を行います。'),
 									array('task' => 'userlist',			'name' => 'ユーザ一覧',			'desc' => 'ログイン可能なユーザを管理します。'),
 									array('task' => 'loginstatus',		'name' => 'ログイン状況',		'desc' => 'ユーザのログイン状況を表示します。'),
 									array('task' => 'configsite',		'name' => '基本情報',			'desc' => 'サイト運営者の設定を行います。'),
