@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 734 2008-06-11 04:49:21Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 1191 2008-11-08 04:55:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -19,10 +19,11 @@ require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 
 class default_contentWidgetContainer extends BaseWidgetContainer
 {
-	var $db;			// DB接続オブジェクト
-	var $_contentCreated;	// コンテンツが取得できたかどうか
-	var $currentDay;		// 現在日
-	var $currentHour;		// 現在時間
+	private $db;			// DB接続オブジェクト
+	private $_contentCreated;	// コンテンツが取得できたかどうか
+	private $currentDay;		// 現在日
+	private $currentHour;		// 現在時間
+	private $headTitle;		// HTMLヘッダタイトル
 	const CONTENT_TYPE = 'ct';		// 参照数カウント用
 		
 	/**
@@ -71,6 +72,7 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		global $gEnvManager;
+		global $gPageManager;
 		
 		// 現在日時を取得
 		$this->currentDay = date("Y/m/d");		// 日
@@ -94,6 +96,8 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 				$this->setAppErrorMsg('IDにエラー値があります');
 			}
 		}
+		// HTMLサブタイトルを設定
+		if (!empty($this->headTitle)) $gPageManager->setHeadSubTitle($this->headTitle);
 	}
 	/**
 	 * 取得したコンテンツ項目をテンプレートに設定する
@@ -116,6 +120,7 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 
 		// タイトルを設定
 		$title = $fetchedRow['cn_name'];
+		if (empty($this->headTitle)) $this->headTitle = $title;
 		
 		// HTMLを出力
 		// 出力内容は特にエラーチェックしない
