@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: qrcodeWidgetContainer.php 420 2008-03-21 02:05:38Z fishbone $
+ * @version    SVN: $Id: qrcodeWidgetContainer.php 1016 2008-09-17 05:28:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -53,20 +53,14 @@ class qrcodeWidgetContainer extends BaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		global $gEnvManager;
-		global $gMailManager;
-		global $gErrorManager;
 		global $gDesignManager;
 		
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		
 		// 設定値の取得
-		$useFixedData = 0;			// 固定データを使用
 		$qrData = '';				// QRコード化するデータ
 		$title = 'QRコード';			// 表示タイトル
 		$desc = '';				// 説明
 		$paramObj = $this->getWidgetParamObj();
 		if (!empty($paramObj)){
-			$useFixedData = $paramObj->useFixedData;			// 固定データを使用
 			$qrData = $paramObj->qrData;						// QRコード化するデータ
 			$title = $paramObj->title;			// 表示タイトル
 			$desc = $paramObj->desc;				// 説明
@@ -74,27 +68,13 @@ class qrcodeWidgetContainer extends BaseWidgetContainer
 		
 		$act = $request->trimValueOf('act');
 		if ($act == 'genarate'){			// QRコード生成のとき
-			ob_end_clean();
-			
 			require_once($gEnvManager->getLibPath() .	'/qr_img0.50g/php/qr_img.php');
-			define ("QRCODE_DATA_PATH", $gEnvManager->getCurrentWidgetRootPath() . '/images');		// 画像作成パスの設定
-
-			Header("Content-type: image/png");
-			$qrData = "matukazu";
-			$qrcode_image = new Qrcode_image;
-			$qrcode_image->qrcode_image_out($qrData, "png");
-			
-			ob_end_flush();
 		} else {
 			// QRコード生成パスを設定
 			$urlparam  = M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET . '&';
 			$urlparam .= M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() .'&';
+			$urlparam .= 'act=genarate&t=P&s=3&d=' . urlencode($qrData);
 			
-			if ($useFixedData){		// 固定データを使用のとき
-				$urlparam .= 'act=genarate&d=' . urlencode($qrData) . '&t=P&s=3';
-			} else {			// ユーザ設定データなしのときは、携帯サイトURLを設定
-				$urlparam .= 'act=genarate&d=' . urlencode($gEnvManager->getDefaultMobileUrl()) . '&t=P&s=3';
-			}
 			$link .= $destImg;
 			$link .= '</a>';
 			$this->tmpl->addVar("_widget", "qr_path", $gEnvManager->getDefaultUrl() . '?' . $urlparam);
