@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: templateChangerWidgetContainer.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version    SVN: $Id: templateChangerWidgetContainer.php 1183 2008-11-07 04:26:53Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -19,7 +19,9 @@ require_once($gEnvManager->getCommonPath() . '/htmlEdit.php');
 
 class templateChangerWidgetContainer extends BaseWidgetContainer
 {
-	var $selectMenuArray = array();
+	private $db;	// DB接続オブジェクト
+	private $selectMenuArray = array();
+	private $currentTemplate;	// 選択中のテンプレート
 
 	/**
 	 * コンストラクタ
@@ -28,6 +30,9 @@ class templateChangerWidgetContainer extends BaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
+		
+		// DB接続オブジェクト作成
+		$this->db = new templateChangerDb();
 	}
 	/**
 	 * ウィジェット単位のアクセス制御
@@ -66,9 +71,10 @@ class templateChangerWidgetContainer extends BaseWidgetContainer
 		global $gEnvManager;
 		global $gDesignManager;
 		
-		// DBオブジェクト作成
-		$db = new templateChangerDb();
-		$db->getTemplates(array($this, 'selectMenuLoop'), $gEnvManager->getCurrentTemplateId());
+		$this->currentTemplate = $gEnvManager->getCurrentTemplateId();// 選択中のテンプレート
+		
+		// すべてのテンプレートを取得
+		$this->db->getAllTemplateList(array($this, 'selectMenuLoop'));
 
 		// テンプレート選択用メニュー作成
 		$html = HtmlEdit::createSelectMenu($this->selectMenuArray, M3_SYSTEM_TAG_CHANGE_TEMPLATE, "class=\"button\" onchange=\"showimage()\" style=\"width:140px;\"");
@@ -89,17 +95,17 @@ class templateChangerWidgetContainer extends BaseWidgetContainer
 	/**
 	 * メニューを作成
 	 *
-	 * @param int		$index			行番号
-	 * @param array		$fetchedRow		取得行
-	 * @param object	$param			任意使用パラメータ
-	 * @return bool						trueを返すとループ続行。falseを返すとその時点で終了。
+	 * @param int    $index			行番号
+	 * @param array  $fetchedRow	取得行
+	 * @param object $param			未使用
+	 * @return bool					trueを返すとループ続行。falseを返すとその時点で終了。
 	 */
 	function selectMenuLoop($index, $fetchedRow, $param)
 	{
 		$menuItems = new SelectMenuItem();
 		$menuItems->name = strlen($fetchedRow['tm_name']) ? $fetchedRow['tm_name'] : $fetchedRow['tm_id'];
 		$menuItems->value = $fetchedRow['tm_id'];
-		if ($menuItems->value == $param) $menuItems->selected = true;
+		if ($menuItems->value == $this->currentTemplate) $menuItems->selected = true;
 		$this->selectMenuArray[] = $menuItems;
 		return true;
 	}
