@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: convert_html.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: convert_html.php 1176 2008-11-05 04:23:39Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -971,10 +971,8 @@ class Body extends Element
 
 	function replace_contents($arr)
 	{
-		$contents  = '<div class="contents">' . "\n" .
-				'<a id="contents_' . $this->id . '"></a>' . "\n" .
-				$this->contents->toString() . "\n" .
-				'</div>' . "\n";
+		//$contents  = '<div class="contents">' . "\n" . '<a id="contents_' . $this->id . '"></a>' . "\n" . $this->contents->toString() . "\n" . '</div>' . "\n";
+		$contents  = '<div class="wiki_content">' . "\n" . '<a id="wiki_content_' . $this->id . '"></a>' . "\n" . $this->contents->toString() . "\n" . '</div>' . "\n";
 		return $contents;
 	}
 }
