@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: rename.inc.php 1095 2008-10-21 08:51:41Z fishbone $
+ * @version    SVN: $Id: rename.inc.php 1161 2008-10-30 08:47:27Z fishbone $
  * @link       http://www.magic3.org
  */
 //
@@ -45,26 +45,26 @@ function plugin_rename_action()
 	} else {
 		// $method == 'page'
 		$page  = plugin_rename_getvar('page');
-		$refer = plugin_rename_getvar('refer');
+		$refer = plugin_rename_getvar('refer');		// 変更元のページ名
 
 		if ($refer == '') {
 			return plugin_rename_phase1();
-
-		} else if (! is_page($refer)) {
+		} else if (!is_page($refer)) {
 			return plugin_rename_phase1('notpage', $refer);
-
 		//} else if ($refer == $whatsnew) {
 		} else if ($refer == WikiConfig::getWhatsnewPage()) {
 			return plugin_rename_phase1('norename', $refer);
-
-		} else if ($page == '' || $page == $refer) {
+		} else if ($page == '' || $page == $refer) {	// 新規ページ名未入力、または、新旧ページ名が同じとき
+			// 新規ページ名入力フィールド表示
 			return plugin_rename_phase2();
-
 		} else if (! is_pagename($page)) {
 			return plugin_rename_phase2('notvalid');
-
+		} else if (is_page($page)){				// 変更先のページが既に存在するとき add by magic3
+			return plugin_rename_phase2('already', $page);
 		} else {
-			return plugin_rename_refer();
+			// ページ名変更処理
+			//return plugin_rename_refer();
+			return plugin_rename_refer($page, $refer);
 		}
 	}
 }
@@ -157,11 +157,13 @@ EOD;
 }
 
 //第二段階:新しい名前の入力
-function plugin_rename_phase2($err = '')
+//function plugin_rename_phase2($err = '')
+function plugin_rename_phase2($err = '', $page = '')
 {
 	global $script, $_rename_messages;
 
-	$msg   = plugin_rename_err($err);
+	//$msg   = plugin_rename_err($err);
+	$msg   = plugin_rename_err($err, $page);
 	$page  = plugin_rename_getvar('page');
 	$refer = plugin_rename_getvar('refer');
 	if ($page == '') $page = $refer;
@@ -218,18 +220,25 @@ EOD;
 }
 
 //ページ名と関連するページを列挙し、phase3へ
-function plugin_rename_refer()
+//function plugin_rename_refer()
+function plugin_rename_refer($page, $refer)
 {
-	$page  = plugin_rename_getvar('page');
-	$refer = plugin_rename_getvar('refer');
-
-	$pages[encode($refer)] = encode($page);
+//	$page  = plugin_rename_getvar('page');
+//	$refer = plugin_rename_getvar('refer');
+	$pages = array();
+	//$pages[encode($refer)] = encode($page);
+	$pages[$refer] = $page;		// 名前を変更するページ自身
 	if (plugin_rename_getvar('related') != '') {
-		$from = strip_bracket($refer);
-		$to   = strip_bracket($page);
-		foreach (plugin_rename_getrelated($refer) as $_page)
-			$pages[encode($_page)] = encode(str_replace($from, $to, $_page));
+		$from = strip_bracket($refer);		// 変更元ページ名
+		$to   = strip_bracket($page);		// 変更先ページ名
+		
+		// 関連ファイルを取得し、関連ファイルの新規ページ名を作成
+		foreach (plugin_rename_getrelated($refer) as $_page){
+			//$pages[encode($_page)] = encode(str_replace($from, $to, $_page));
+			$pages[$_page] = $to . substr($_page, strlen($from));
+		}
 	}
+	// $pagesには、「$pages[旧ページ名]=[新規ページ名]」の形式で変更対象のページ名がすべて格納されている
 	return plugin_rename_phase3($pages);
 }
 
@@ -245,27 +254,34 @@ function plugin_rename_regex($arr_from, $arr_to)
 		return plugin_rename_phase1('already', $exists);
 	} else {
 		$pages = array();
-		foreach ($arr_from as $refer)
-			$pages[encode($refer)] = encode(array_shift($arr_to));
+		foreach ($arr_from as $refer){
+			//$pages[encode($refer)] = encode(array_shift($arr_to));
+			$pages[$refer] = array_shift($arr_to);
+		}
 		return plugin_rename_phase3($pages);
 	}
 }
 
 function plugin_rename_phase3($pages)
 {
+	// $pagesには、「$pages[旧ページ名]=[新規ページ名]」の形式で変更対象のページ名がすべて格納されている
 	global $script, $_rename_messages;
 
 	$msg = $input = '';
+	
+	// 名前を変更するファイルを取得(アップロードディレクトリ内)
 	$files = plugin_rename_get_files($pages);
 
+	// 変更先のファイルの存在をチェック。存在する場合は削除するため
 	$exists = array();
-	foreach ($files as $_page=>$arr)
-		foreach ($arr as $old=>$new)
-			if (file_exists($new))
-				$exists[$_page][$old] = $new;
+	foreach ($files as $_page=>$arr){
+		foreach ($arr as $old=>$new){
+			if (file_exists($new)) $exists[$_page][$old] = $new;
+		}
+	}
 
 	$pass = plugin_rename_getvar('pass');
-	if ($pass != '' && pkwk_login($pass)) {
+	if ($pass != '' && pkwk_login($pass)) {		// パスワードの入力チェック
 		return plugin_rename_proceed($pages, $files, $exists);
 	} else if ($pass != '') {
 		$msg = plugin_rename_err('adminpass');
@@ -293,9 +309,11 @@ function plugin_rename_phase3($pages)
 	if (! empty($exists)) {
 		$msg .= $_rename_messages['err_already_below'] . '<ul>';
 		foreach ($exists as $page=>$arr) {
-			$msg .= '<li>' . make_pagelink(decode($page));
+			//$msg .= '<li>' . make_pagelink(decode($page));
+			$msg .= '<li>' . make_pagelink($page);
 			$msg .= $_rename_messages['msg_arrow'];
-			$msg .= htmlspecialchars(decode($pages[$page]));
+			//$msg .= htmlspecialchars(decode($pages[$page]));
+			$msg .= htmlspecialchars($pages[$page]);
 			if (! empty($arr)) {
 				$msg .= '<ul>' . "\n";
 				foreach ($arr as $ofile=>$nfile)
@@ -334,39 +352,35 @@ EOD;*/
 <form action="$postScript" method="post">
  <div>
   <input type="hidden" name="plugin" value="rename" />
+  <input type="hidden" name="pass" />
   $input
   <label for="_p_rename_adminpass">{$_rename_messages['msg_adminpass']}</label>
-  <input type="password" name="pass" id="_p_rename_adminpass" value="" />
-  <input type="submit" value="{$_rename_messages['btn_submit']}" />
+  <input type="password" name="password" id="_p_rename_adminpass" size="12" />
+  <input type="submit" value="{$_rename_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 <p>{$_rename_messages['msg_confirm']}</p>
 EOD;
 
-	ksort($pages);
+	//ksort($pages);
 	$ret['body'] .= '<ul>' . "\n";
-	foreach ($pages as $old=>$new)
-		$ret['body'] .= '<li>' .  make_pagelink(decode($old)) .
-			$_rename_messages['msg_arrow'] .
-			htmlspecialchars(decode($new)) .  '</li>' . "\n";
+	foreach ($pages as $old=>$new){
+		//$ret['body'] .= '<li>' .  make_pagelink(decode($old)) . $_rename_messages['msg_arrow'] . htmlspecialchars(decode($new)) .  '</li>' . "\n";
+		$ret['body'] .= '<li>' .  make_pagelink($old) . $_rename_messages['msg_arrow'] . htmlspecialchars($new) .  '</li>' . "\n";
+	}
 	$ret['body'] .= '</ul>' . "\n";
 	return $ret;
 }
-
 function plugin_rename_get_files($pages)
 {
+	// $pagesには、「$pages[旧ページ名]=[新規ページ名]」の形式で変更対象のページ名がすべて格納されている
 	$files = array();
-	$dirs  = array(BACKUP_DIR, DIFF_DIR, DATA_DIR);
+	/*$dirs  = array(BACKUP_DIR, DIFF_DIR, DATA_DIR);
 	if (exist_plugin_convert('attach'))  $dirs[] = UPLOAD_DIR;
 	if (exist_plugin_convert('counter')) $dirs[] = COUNTER_DIR;
-	// and more ...
-
-foreach ($pages as $from=>$to) {
-	echo $from.'-'. $to.'<br>';
-}
-return $files;
-
-
+	*/
+	// アップロードディレクトリを検索
+	$dirs = array(UPLOAD_DIR);
 
 	$matches = array();
 	foreach ($dirs as $path) {
@@ -376,40 +390,96 @@ return $files;
 		while ($file = readdir($dir)) {
 			if ($file == '.' || $file == '..') continue;
 
-			foreach ($pages as $from=>$to) {
-				$pattern = '/^' . str_replace('/', '\/', $from) . '([._].+)$/';
+			foreach ($pages as $from => $to) {
+				$encodeFrom = encode($from);
+				$encodeTo = encode($to);
+				//$pattern = '/^' . str_replace('/', '\/', $from) . '([._].+)$/';
+				$pattern = '/^' . str_replace('/', '\/', $encodeFrom) . '([._].+)$/';
 				if (! preg_match($pattern, $file, $matches))
 					continue;
 
-				$newfile = $to . $matches[1];
+				//$newfile = $to . $matches[1];
+				$newfile = $encodeTo . $matches[1];
 				$files[$from][$path . $file] = $path . $newfile;
 			}
 		}
 	}
 	return $files;
 }
-
+// ページデータの実際の移行処理
 function plugin_rename_proceed($pages, $files, $exists)
 {
 	global $now, $_rename_messages;
 
-	if (plugin_rename_getvar('exist') == '')
+	if (plugin_rename_getvar('exist') == ''){
 		foreach ($exists as $key=>$arr)
 			unset($files[$key]);
-
-	set_time_limit(0);
-	foreach ($files as $page=>$arr) {
-		foreach ($arr as $old=>$new) {
-			if (isset($exists[$page][$old]) && $exists[$page][$old])
-				unlink($new);
-			rename($old, $new);
-
-			// linkデータベースを更新する BugTrack/327 arino
-			links_update($old);
-			links_update($new);
-		}
 	}
 
+	// アップロードディレクトリ内のファイルの名前を更新
+	set_time_limit(0);
+	foreach ($files as $page => $arr) {
+		// 添付ファイルの情報取得
+		$newLines = array();
+		$lines = WikiPage::getPageUpload($page);
+				
+		foreach ($arr as $old => $new) {
+			// 変更先のファイルを削除
+			$ret = true;
+			if (isset($exists[$page][$old]) && $exists[$page][$old]) $ret = unlink($new);
+			
+			// ファイル名変更
+			$ret = rename($old, $new);
+			
+			// ファイル名変更に成功した場合は、ファイル情報を更新
+			$oldFilename = basename($old);
+			$newFilename = basename($new);
+			if ($ret){
+				// ##### 添付ファイル情報を更新 #####
+				// 1レコード(行)のパターンは、「ファイル名」「元のファイル名」「ファイルハッシュキー」「世代番号」「アクセスカウント数」「凍結状態」をタブ区切りで格納
+				for ($i = 0; $i < count($lines); $i++){
+					$lineData = rtrim($lines[$i]);
+					if (empty($lineData)) continue;
+	
+					list($filename, $originalFilename, $md5, $age, $count, $freeze) = explode("\t", $lineData);
+					if ($filename == $oldFilename){
+						// 新規データ追加
+						$newLine = '';
+						$newLine .= $newFilename . "\t";		// 新規ファイル名
+						$newLine .= $originalFilename . "\t";	// 元のファイル名
+						$newLine .= $md5 . "\t";				// ファイルハッシュキー
+						$newLine .= '' . "\t";	// age
+						$newLine .= '0' . "\t";	// count
+						$newLine .= '' . "\n";	// freeze
+						$newLines[] = $newLine;
+						break;
+					}
+				}
+			}
+			// linkデータベースを更新する BugTrack/327 arino
+			//links_update($old);
+			//links_update($new);
+		}
+		// 新規ページの添付ファイル情報を更新
+		WikiPage::updatePageUpload($pages[$page], join('', $newLines));
+	}
+
+	// データの移行処理
+	foreach ($pages as $oldPage => $newPage){
+		// ページ名を変更
+		WikiPage::renamePage($oldPage, $newPage);
+	}
+	
+	// ##### データ移行完了後の処理 #####
+	// リンク更新
+	foreach ($pages as $oldPage => $newPage){
+		links_update($newPage);
+	}
+		
+	// 最終更新ファイルアップデート
+	put_lastmodified();
+
+	// 名前変更のログを残す
 	$postdata = get_source(PLUGIN_RENAME_LOGPAGE);
 	$postdata[] = '*' . $now . "\n";
 	if (plugin_rename_getvar('method') == 'regex') {
@@ -425,8 +495,8 @@ function plugin_rename_proceed($pages, $files, $exists)
 	if (! empty($exists)) {
 		$postdata[] = "\n" . $_rename_messages['msg_result'] . "\n";
 		foreach ($exists as $page=>$arr) {
-			$postdata[] = '-' . decode($page) .
-				$_rename_messages['msg_arrow'] . decode($pages[$page]) . "\n";
+			//$postdata[] = '-' . decode($page) . $_rename_messages['msg_arrow'] . decode($pages[$page]) . "\n";
+			$postdata[] = '-' . $page . $_rename_messages['msg_arrow'] . $pages[$page] . "\n";
 			foreach ($arr as $ofile=>$nfile)
 				$postdata[] = '--' . $ofile .
 					$_rename_messages['msg_arrow'] . $nfile . "\n";
@@ -434,9 +504,10 @@ function plugin_rename_proceed($pages, $files, $exists)
 		$postdata[] = '----' . "\n";
 	}
 
-	foreach ($pages as $old=>$new)
-		$postdata[] = '-' . decode($old) .
-			$_rename_messages['msg_arrow'] . decode($new) . "\n";
+	foreach ($pages as $old=>$new){
+		//$postdata[] = '-' . decode($old) . $_rename_messages['msg_arrow'] . decode($new) . "\n";
+		$postdata[] = '-' . $old . $_rename_messages['msg_arrow'] . $new . "\n";
+	}
 
 	// 更新の衝突はチェックしない。
 
